@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.50.2.1.2.27 $
+// $Revision: 1.50.2.1.2.30 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -154,7 +154,7 @@ function xnppaperGetListBlock( $item_basic ) {
   // set to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -182,7 +182,7 @@ function xnppaperGetDetailBlock( $item_id ) {
   $assoc = $chandler->getConfigsByCat( false, $module->mid() );
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -214,7 +214,7 @@ function xnppaperGetPrinterFriendlyDetailBlock( $item_id ) {
   $assoc = $chandler->getConfigsByCat( false, $module->mid() );
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -254,7 +254,7 @@ function xnppaperGetRegisterBlock() {
 
   // assingn to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // variables assigned to xoopsTpl are copied to $tpl
   $tpl->assign( 'basic', $basic );
@@ -274,6 +274,7 @@ function xnppaperGetRegisterBlock() {
 function xnppaperGetEditBlock( $item_id ) {
   global $xoopsDB;
   $formdata =& xoonips_getutility( 'formdata' );
+  $textutil =& xoonips_getutility( 'text' );
 
   // retrieve blocks of BasicInformation / index
   $basic = xnpGetBasicInformationEditBlock( $item_id );
@@ -281,13 +282,9 @@ function xnppaperGetEditBlock( $item_id ) {
   $paper_pdf_reprint = xnpGetAttachmentEditBlock( $item_id, 'paper_pdf_reprint' );
 
   // retrieve DetailInformation
-  // TODO: author is always empty,
-  $author = $formdata->getValue( 'post', 'author', 's', false );
-  if ( isset( $author ) ) {
+  $title = $formdata->getValue( 'post', 'title', 's', false );
+  if ( isset( $title ) ) {
     $detail = _xnppaper_get_form_request();
-    foreach ( $detail as $key => $val ) {
-      $$key = $val;
-    }
   } else if ( ! empty( $item_id ) ) {
     $detail = xnppaperGetDetailInformation( $item_id );
     $item = array();
@@ -295,10 +292,13 @@ function xnppaperGetEditBlock( $item_id ) {
   } else {
     $detail = array();
   }
+  foreach ( $detail as $key => $val ) {
+    $detail[$key] = $textutil->html_special_chars( $detail[$key] );
+  }
 
   // assign to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // variables assigned to xoopsTpl are copied to $tpl
   $tpl->assign( 'basic', $basic );
@@ -375,7 +375,7 @@ function xnppaperGetConfirmBlock( $item_id ) {
 
   // assign to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -616,7 +616,7 @@ function xnppaperGetAdvancedSearchBlock( &$search_var ) {
 
   // assign to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // variables assigned to xoopsTpl are copied to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
