@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.5.2.1.2.2 $
+// $Revision: 1.5.2.1.2.3 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2009 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -24,25 +24,39 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-define( 'XLHTML_FAILED', 'xlhtml failed.' );
+/**
+ * file search plugin class for Excel
+ */
+class XooNIpsFileSearchPluginEXCEL extends XooNIpsFileSearchPlugin {
 
-class XoonipsExcel extends XoonipsSearchTextExtractor {
-  function XoonipsExcel() {
+  /**
+   * constractor
+   */
+  function XooNIpsFileSearchPluginEXCEL() {
+    parent::XooNIpsFileSearchPlugin();
+    $this->is_xml = true;
+    $this->is_utf8 = true;
   }
-  
-  function openNowin( $filename ) {
+
+  /**
+   * open file resource
+   *
+   * @acccess protected
+   * @param string $filename file name
+   */
+  function _open_file( $filename ) {
     $cmd = sprintf( 'xlhtml %s', escapeshellarg( $filename ) );
     $this->handle = @popen( $cmd, 'rb' );
   }
-  
-  function close() {
+
+  /**
+   * close file resource
+   *
+   * @acccess protected
+   */
+  function _close_file() {
     @pclose( $this->handle );
-    $this->handle = false;
   }
-  
-  function fetch() {
-    return $this->fetchFromHtml();
-  }
-};
+}
 
 ?>
