@@ -1,8 +1,8 @@
 <?php
-// $Revision: 1.5.2.1.2.2 $
+// $Revision: 1.5.2.1.2.3 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
-//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  Copyright (C) 2005-2009 RIKEN, Japan All rights reserved.                //
 //  http://xoonips.sourceforge.jp/                                           //
 // ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
@@ -24,40 +24,39 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 // ------------------------------------------------------------------------- //
-define( 'PDFTOTEXT_FAILED', 'pdftotext failed.' );
+/**
+ * file search plugin class for PDF
+ */
+class XooNIpsFileSearchPluginPDF extends XooNIpsFileSearchPlugin {
 
-class XoonipsPdf extends XoonipsSearchTextExtractor {
-  function XoonipsPdf() {
-  }
-  
-  function openNowin( $filename ) {
-    $cmd = sprintf( 'pdftotext -q -enc UTF-8 %s -', escapeshellarg( $filename ) );
-    $this->handle = @popen( $cmd, 'rb' );
-  }
-  
-  function close() {
-    @pclose( $this->handle );
-    $this->handle = false;
+  /**
+   * constractor
+   */
+  function XooNIpsFileSearchPluginPDF() {
+    parent::XooNIpsFileSearchPlugin();
+    $this->is_xml = false;
+    $this->is_utf8 = true;
   }
 
   /**
-   * extract text from file
-   *   @return array( text, errorMessage )
-   *    success:
-   *      text: extracted utf8 encoded string
-   *      errorMessage: false
-   *    failure:
-   *      text:  false
-   *      errorMessage: error message
+   * open file resource
+   *
+   * @acccess protected
+   * @param string $filename file name
    */
-  function fetch() {
-    list( $text, $message ) = $this->fetchFromHtml();
-    if ( $text !== false ) {
-      // remove FORM FEED character
-      $text = str_replace( "\x0c", '', $text );
-    }
-    return array( $text, $message );
+  function _open_file( $filename ) {
+    $cmd = sprintf( 'pdftotext -q -enc UTF-8 %s -', escapeshellarg( $filename ) );
+    $this->handle = @popen( $cmd, 'rb' );
   }
-};
+
+  /**
+   * close file resource
+   *
+   * @acccess protected
+   */
+  function _close_file() {
+    @pclose( $this->handle );
+  }
+}
 
 ?>
