@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.16 $
+// $Revision: 1.1.4.1.2.17 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -359,10 +359,15 @@ define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_MIMETYPE', 'MIME Type' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_SUFFIX', 'Suffix' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_VERSION', 'Version' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCAN', 'Rescan' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCANNING', 'Rescanning Now...' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_TITLE', 'File Search Plugins' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_EMPTY', 'No plugins found.' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_LABEL_FILECOUNT', 'Registered Files' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_TITLE', 'Rescan All Files');
-define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_DESC', 'If you want to rebuild file search indexes, push following button.' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_TITLE', 'Update File Information' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_DESC', 'Rescan all files for updating file informations (MIME Type and Thumbnail)' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_TITLE', 'Update File Search Index' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_DESC', 'Rescan all files for rebuilding full-text search indexes.' );
 
 // >> oaipmh maintenance
 define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_LABEL_LASTRESULT', 'Result' );
