@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.3 $
+// $Revision: 1.1.2.4 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -59,7 +59,7 @@ define( '_AM_XOONIPS_LABEL_UNAME', 'ユーザ名' );
 define( '_AM_XOONIPS_LABEL_NAME', '本名' );
 define( '_AM_XOONIPS_LABEL_EMAIL', 'メールアドレス' );
 define( '_AM_XOONIPS_LABEL_POSITION', '職名' );
-define( '_AM_XOONIPS_LABEL_DIVISION', '所属' );
+define( '_AM_XOONIPS_LABEL_DIVISION', '部門/研究室' );
 define( '_AM_XOONIPS_LABEL_COMPANY_NAME', '機関名/大学名/会社名' );
 define( '_AM_XOONIPS_LABEL_TEL', '電話番号' );
 define( '_AM_XOONIPS_LABEL_FAX', 'FAX番号' );
@@ -359,10 +359,15 @@ define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_MIMETYPE', 'MIME Type' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_SUFFIX', '拡張子' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_VERSION', 'バージョン' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCAN', '再スキャン' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_LABEL_RESCANNING', 'スキャン中' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_TITLE', '利用可能な検索プラグイン' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_PLUGINS_EMPTY', '利用可能な検索プラグインが存在しません' );
 define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_TITLE', '全ファイルの再スキャン' );
-define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_DESC', '全てのファイルをスキャンして検索用インデックスを再構築するには次のボタンを押してください' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_LABEL_FILECOUNT', '登録済みファイル数' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_TITLE', 'ファイル情報の更新' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INFO_DESC', '全てのファイルをスキャンしてファイルの詳細情報(MIME Type，サムネイル画像)を更新します' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_TITLE', '検索インデックスの更新' );
+define( '_AM_XOONIPS_MAINTENANCE_FILESEARCH_RESCAN_INDEX_DESC', '全てのファイルをスキャンして検索用インデックスを再構築します' );
 // >> oaipmh maintenance
 define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_LABEL_LASTRESULT', '実行結果' );
 define( '_AM_XOONIPS_MAINTENANCE_OAIPMH_RESULTS_TITLE', '最新の実行結果' );
